(* ::Package:: *)

(*Title: Resptract, Respiratory tract model of ICRP66 *)

(* :Author: Guillermo Sanchez *)

(* :Summary:
This package provides analytical  method to solve the respiratory tract model  
according to ICRP 66.It has been developped with the support of ENUSA Industrias 
Avanzadas, http://www.enusa.es*)

(* :Context: Biokmod`Resptract` *)

(* :Package Version: 1.2. *)

(* :Copyright: Copyright 2005, Guillermo Sanchez. guillermo@usal.es.*)

(* :History: 1.0 February 2004, 1.1 September 2004, 1.2 June 2005*)

(* :Keywords: Compartmental Models, ICRP 66*)

(* :Sources: ICRP 66*)

(* :Warning:  *)

(* :Mathematica Version: 5.1*)

(* :Limitation: None known. *)

(* :Discussion: *)


BeginPackage["Biokmod`Resptract`","Biokmod`Master`"]

qRespTract::"usage" = "qRespTract[int, {AI, bbfastseq, bbslow, BBfastseq, BBslow, ET2, ET1}, 
{\!\(s\_p, s\_pt, s\_t\)}, t, lambda, options], for one specific nuclide, 
gives the  retention in the respiratory tract compartments -numbered according to ICRP 66- 
at time t, in days, after of a single intake <int> in t = 0.  
AI, bbfastseq, bbslow, BBfastseq, BBslow,  ET2 and ET1  are the initial  fractional 
deposition. It can be obtanined using AMADXXX package funtion (Recommended values for 
reference workers as a function of aerosol size can be obtained from Annex F of ICRP 66).
\!\(s\_p, s\_pt, s\_t\) are the dissolution rates and lambda is the decay constant, 
in \!\(days\^-1\). Information about the options, including the default values, 
can be shown with Options[qRespTract]. 
Note: \!\(bb\_(fast+seq)\) = \!\(bb\_1(fast)\) + \!\(bb\_seq\), 
bb = \!\(bb\_(fast+seq)\) + \!\(bb\_2(slow)\), \!\(BB\_(fast+seq)\) = 
\!\(BB\_1(fast)\) + \!\(BB\_seq\), and BB = \!\(BB\_(fast+seq)\) + \!\(BB\_2(slow)\).";

qRT2::"usage" = "qRT2[int, IDF , DR, t, lambda, options], 
for one specific nuclide, gives the  retention in the respiratory tract compartments,
refered as symbols in place of numbered, at time t, in days,after of a single 
intake <int> in t = 0, being IFD the initial 
fractional deposition:{AI, bbfastseq, bbslow, BBfastseq, BBslow, ET2, ET1}, and DR the 
are the dissolution rates { \!\(s\_p, s\_pt, s\_t\) }  and lambda is the decay constant, 
in \!\(days\^-1\, see also qRespTract Help";


qLungs::"usage" = " qLungs[int, {AI, bbfastseq, bbslow, BBfastseq, BBslow, 
ET2, ET1}, {\!\(s\_p, s\_pt, s\_t\)}, t, lambda, options], for one specific nuclide, 
gives 
the  retention in the lungs (thoracic) at time t, in days, after 
of a single intake <int> in t = 0.  AI, bbfastseq, bbslow, BBfastseq, BBslow, 
ET2 and ET1 are the initial  fractional deposition (Recommended values for reference 
workers as a function
of aerosol size can be obtained from Annex F of ICRP 66).  \!\(s\_p, s\_pt, s\_t\) are the 
dissolution rates and lambda is the decay constant, in \!\(days\^-1\) . 
Information about the options, including the default values, can be shown with Options[qLungs]. 
Note: \!\(bb\_(fast+seq)\) = \!\(bb\_1(fast)\) + \!\(bb\_seq\), 
bb = \!\(bb\_(fast+seq)\) + \!\(bb\_2(slow)\), \!\(BB\_(fast+seq)\) = 
\!\(BB\_1(fast)\) + \!\(BB\_seq\), and BB = \!\(BB\_(fast+seq)\) + \!\(BB\_2(slow)\).";

RespiratoryTract::usage = "RespiratoryTract[{int, t}, {AI, bbfastseq, bbslow, 
BBfastseq, BBslow, ET2, ET1},{\!\(s\_p, s\_pt, s\_t\)}, t1, lambda, options], for one specific nuclide, 
gives the  retention in each compartment of ICRP66 model at time t, in days, for a 
continuous intake <int(t)>. AI, bbfastseq, bbslow, BBfastseq, BBslow , ET2, 
ET1 are  the initial fractional deposition in AI,  \!\(bb\_(fast+seq)\),  
\!\(bb\_2(slow)\),  \!\(BB\_(fast+seq)\),  \!\(BB\_2(slow)\) , ET2 and ET1";

LungsRetention::usage = "LungsRetention[int, {AI, bbfastseq, bbslow, 
BBfastseq, BBslow, ET2, ET1},{sp, spt, st}, t1, lambda, options] for one specific nuclide gives the 
retention in Lungs at time t1 (in days) after the intake. An acute intake is assumed by default. 
With Options can be chosen other intake types: Constant, Continuous and MultiInputs 
Intake, in this last case inp must be written {{I0, t0},...,{In, tn}}, then t1 is the time after the 
last intake, so for t1  is taken tn = 0 ";
 

AMADfit::usage = "AMADfit[x] gives an ajusted function of the fractional 
deposition values for AMAD x , where x can be a parameter. This function 
is applicable when 0.5<=x<=20. It has been obtained fitting the values given 
in  Annex F -workers- of ICRP 66.";

AMADAdultW::usage = "AMADAdultW[x] gives the fractional deposition values 
for reference Adult worker, being x AMAD , with 0.001<=x<=20 "; 

AMADAdultP::usage = "AMADAdultP[x] gives the fractional deposition values 
for an Adult member of the public, being x AMAD, with 0.001<=x<=10 "; 

AMADyr1::usage = "AMADyr1[x] gives the fractional deposition values 
for an child 1 year old, being x AMAD, with 0.001<=x<=10 "; 

AMADyr10::usage = "AMADyr10[x] gives the fractional deposition values 
for an child 10 year old, being x AMAD in micrometres, with 0.5<=x<=10"; 

Options[qRespTract] = {fAI1 -> 0.3, fAI2 -> 0.6, fAI3 -> 0.1, fbs -> 0.007, 
fBs -> 0.007, fet2 -> 0.9995, 
Subscript[k, "AI1,bb1"] -> 0.02, 
Subscript[k, "AI2,bb1"] -> 0.001, 
Subscript[k, "AI3,bb1"] -> 0.0001, 
Subscript[k, "AI3,TH"] -> 0.00002, 
Subscript[k, "bb1,BB1"] -> 2, 
Subscript[k, "bb2,BB1"] -> 0.03, 
Subscript[k, "bbseq,TH"] -> 0.01, 
Subscript[k, "BB1,ET2"] -> 10, 
Subscript[k, "BB2,ET2"] -> 0.03, 
Subscript[k, "BBseq,TH"] -> 0.01, 
Subscript[k, "ET2,ST"] -> 100, 
Subscript[k, "ETseq,ET"] -> 0.001, 
Subscript[k, Env] -> 1};

Options[qRT2]= Options[qRespTract];
Options[qBfromRT]= Options[qRespTract];
Options[qSTfromRT]= Options[qRespTract];

Options[qLungs] = {fAI1 -> 0.3, fAI2 -> 0.6, 
fAI3 -> 0.1, fbs -> 0.007, fBs -> 0.007, 
Subscript[k, "AI1,bb1"] -> 0.02, Subscript[k, "AI2,bb1"] -> 0.001, 
Subscript[k, "AI3,bb1"] -> 0.0001, Subscript[k, "AI3,TH"] -> 0.00002, 
Subscript[k, "bb1,BB1"] -> 2, Subscript[k, "bb2,BB1"] -> 0.03, 
Subscript[k, "bbseq,TH"] -> 0.01, Subscript[k, "BB1,ET2"] -> 10, 
Subscript[k, "BB2,ET2"] -> 0.03, Subscript[k, "BBseq,TH"] -> 0.01, 
Subscript[k, "ETseq,ET"] -> 0.001};

Options[RespiratoryTract]= Flatten[{IntakeType-> "Acute", Options[qRespTract]}];

Options[LungsRetention]=   Flatten[{IntakeType-> "Acute", Options[qLungs]}];

Begin["`Private`"]

qContinuousRT[input_,acute_List,t_,t1_]:=
    Module[{integrate,t2,y,z,a,b,c,d,tau,m1,m2,m3,m4,r,i},
      integrate[y_+z_,t2_]:=integrate[y,t2]+integrate[z,t2];
      integrate[c_*y_,t2_]:=c*integrate[y,t2]/;FreeQ[c,t2]&&FreeQ[c,tau];
      integrate[E^((b_.)*t2_+(c_.)*tau),t2_]:=(E^(b*t2)*(E^(c*t2)-1))/c/;
          FreeQ[{b,c},t2]&&FreeQ[{b,c},tau];
      integrate[Exp[(a_.)*tau],t2_]:=(E^(a*t2)-1)/a/;
          FreeQ[a,t2]&&FreeQ[a,tau];
      integrate[c_,t2_]:=c*t2/;FreeQ[c,t2]&&FreeQ[c,tau];
      integrate[a_,t2_]:=Integrate[a,{tau,0,t2}]/;!FreeQ[a,tau];m1=acute;
      m2=m1/.t->tau;
      m3=input/.t->t-tau;
      m4=Chop[ExpandAll[m2*m3]]/.E^((b_.)*t2_+(c_.)*tau+(d_.)*tau)->
            E^(b*t2+(c+d)*tau);
      r=Chop[ExpandAll[(integrate[#1,t]&)/@m4]];r/.t->t1];

Q[n_] := Block[{b, k, K, j, p, t}, Subscript[b, 1]*
Sum[1/(E^(Subscript[K, j]*t)*Product[Subscript[K, p] - Subscript[K, j], {p, 1, j - 1}]*
Product[Subscript[K, p] - Subscript[K, j], {p, j + 1, n}]), {j, 1, n}]*
     Product[Subscript[\[Lambda], j], {j, 1, n - 1}]]; 


{Subscript[q11A, AI1][t_], Subscript[q11A, bb1][t_], Subscript[q11A, BB1][t_], 
  Subscript[q11A, ET2][t_], Subscript[q11A, ST][t_]} = 
  Table[Q[i], {i, 1, 5}] /. {Subscript[b, 1] -> AI1o, 
  Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
  Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
  Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
  Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], 
  Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
  Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], Subscript[K, 4] -> 
  Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[K, 5] -> 0}; 

Subscript[q11B, B][t_] = Q[5] /. {Subscript[b, 1] -> AI1o, 
  Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
  Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
  Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
  Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], 
  Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
  Subscript[\[Lambda], 4] -> sp, Subscript[K, 4] -> Subscript[k, "ET2,ST"] 
  + Subscript[k, st], Subscript[K, 5] -> 0}; 

Subscript[q11C, B][t_] = Q[4] /. {Subscript[b, 1] -> AI1o, 
  Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
  Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
  Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
  Subscript[k, st], Subscript[\[Lambda], 3] -> sp, Subscript[K, 3] -> 
  Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[K, 4] -> 0}; 

Subscript[q11D, B][t_] = Q[3] /. {Subscript[b, 1] -> AI1o, 
Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q11E, B][t_] = Q[2] /. {Subscript[b, 1] -> AI1o, 
Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "AI1,bb1"] + 
Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q11At, AI1][t_], Subscript[q11At, bb1][t_], 
 Subscript[q11At, BB1][t_], Subscript[q11At, ET2][t_], 
 Subscript[q11At, ST][t_]} = Table[Q[i], {i, 2, 6}] /. 
 {Subscript[b, 1] -> AI1o, Subscript[\[Lambda], 1] -> spt, 
  Subscript[K, 1] -> Subscript[k, "AI1,bb1"] + Subscript[k, st], 
  Subscript[\[Lambda], 2] -> Subscript[k, "AI1,bb1"], Subscript[K, 2] -> 
  Subscript[k, "AI1,bb1"] + ss, Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], 
  Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
  Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], 
  Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

Subscript[q11Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI1o, 
Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI1,bb1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "AI1,bb1"], 
     Subscript[K, 2] -> Subscript[k, "AI1,bb1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> ss, 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q11Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI1,bb1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "AI1,bb1"], 
     Subscript[K, 2] -> Subscript[k, "AI1,bb1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q11Dt, B][t_] = Q[4] /. {Subscript[b, 1] -> AI1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI1,bb1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "AI1,bb1"], 
     Subscript[K, 2] -> Subscript[k, "AI1,bb1"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[K, 4] -> 0}; 

Subscript[q11Et, B][t_] = Q[3] /. {Subscript[b, 1] -> AI1o, 
Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI1,bb1"] + 
Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
Subscript[k, "AI1,bb1"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q12At, bb1][t_], Subscript[q12At, BB1][t_], 
    Subscript[q12At, ET2][t_], Subscript[q12At, ST][t_]} = 
   Table[Q[i], {i, 3, 6}] /. {Subscript[b, 1] -> AI1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], Subscript[K, 5] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

Subscript[q12Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> ss, 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

Subscript[q12Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI1o, 
Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> ss, 
Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
Subscript[K, 5] -> 0}; 

Subscript[q12Dt, B][t_] = Q[4] /. {Subscript[b, 1] -> AI1o, 
Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
Subscript[K, 4] -> 0}; 

{Subscript[q13At, BB1][t_], Subscript[q13At, ET2][t_], 
    Subscript[q13At, ST][t_]} = Table[Q[i], {i, 4, 6}] /. 
    {Subscript[b, 1] -> AI1o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "AI1,bb1"], Subscript[K, 1] -> Subscript[k, "AI1,bb1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], Subscript[K, 5] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

Subscript[q13Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI1o, 
Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
 Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
 Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 4] -> 
 Subscript[k, "BB1,ET2"], Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
Subscript[\[Lambda], 5] -> ss, Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
Subscript[K, 6] -> 0}; 

Subscript[q13Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 5] -> 0}; 

{Subscript[q14At, ET2][t_], Subscript[q14At, ST][t_]} = 
   Table[Q[i], {i, 5, 6}] /. {Subscript[b, 1] -> AI1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 4] -> spt, Subscript[K, 4] -> Subscript[k, "ET2,ST"] + 
       Subscript[k, st], Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q14Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI1,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI1,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 4] -> spt, Subscript[K, 4] -> Subscript[k, "ET2,ST"] + 
       Subscript[k, st], Subscript[\[Lambda], 5] -> ss, Subscript[K, 5] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

{Subscript[q21A, AI2][t_], Subscript[q21A, bb1][t_], Subscript[q21A, BB1][t_], 
    Subscript[q21A, ET2][t_], Subscript[q21A, ST][t_]} = 
   Table[Q[i], {i, 1, 5}] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], Subscript[K, 4] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[K, 5] -> 0}; 

Subscript[q21B, B][t_] = Q[5] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 4] -> sp, Subscript[K, 4] -> Subscript[k, "ET2,ST"] + 
       Subscript[k, st], Subscript[K, 5] -> 0}; 

Subscript[q21C, B][t_] = Q[4] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> sp, Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[K, 4] -> 0}; 

Subscript[q21D, B][t_] = Q[3] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[K, 3] -> 0}; 

Subscript[q21E, B][t_] = Q[2] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "AI2,bb1"] + 
       Subscript[k, st], Subscript[K, 2] -> 0}; 
{Subscript[q21At, AI2][t_], Subscript[q21At, bb1][t_], 
    Subscript[q21At, BB1][t_], Subscript[q21At, ET2][t_], 
    Subscript[q21At, ST][t_]} = Table[Q[i], {i, 2, 6}] /. 
    {Subscript[b, 1] -> AI2o, Subscript[\[Lambda], 1] -> spt, 
     Subscript[K, 1] -> Subscript[k, "AI2,bb1"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "AI2,bb1"], Subscript[K, 2] -> 
      Subscript[k, "AI2,bb1"] + ss, Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], Subscript[K, 4] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q21Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI2,bb1"] + 
 Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "AI2,bb1"], 
     Subscript[K, 2] -> Subscript[k, "AI2,bb1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> ss, 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q21Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI2o, 
 Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI2,bb1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "AI2,bb1"], 
     Subscript[K, 2] -> Subscript[k, "AI2,bb1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q21Dt, B][t_] = Q[4] /. {Subscript[b, 1] -> AI2o, 
Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI2,bb1"] + 
Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "AI2,bb1"], 
Subscript[K, 2] -> Subscript[k, "AI2,bb1"] + ss, Subscript[\[Lambda], 3] -> ss, 
Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
Subscript[K, 4] -> 0}; 

Subscript[q21Et, B][t_] = Q[3] /. {Subscript[b, 1] -> AI2o, 
Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, 
"AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
Subscript[k, "AI2,bb1"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q22At, bb1][t_], Subscript[q22At, BB1][t_], 
    Subscript[q22At, ET2][t_], Subscript[q22At, ST][t_]} = 
   Table[Q[i], {i, 3, 6}] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], Subscript[K, 5] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

Subscript[q22Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> ss, 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q22Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, Subscript[K, 5] -> 0}; 

Subscript[q22Dt, B][t_] = Q[4] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
     Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[K, 4] -> 0}; 

{Subscript[q23At, BB1][t_], Subscript[q23At, ET2][t_], 
    Subscript[q23At, ST][t_]} = Table[Q[i], {i, 4, 6}] /. 
    {Subscript[b, 1] -> AI2o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "AI2,bb1"], Subscript[K, 1] -> Subscript[k, "AI2,bb1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], Subscript[K, 5] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

Subscript[q23Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 4] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 5] -> ss, Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q23Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 5] -> 0}; 

{Subscript[q24At, ET2][t_], Subscript[q24At, ST][t_]} = 
   Table[Q[i], {i, 5, 6}] /. {Subscript[b, 1] -> AI2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 4] -> spt, Subscript[K, 4] -> Subscript[k, "ET2,ST"] + 
      Subscript[k, st], Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q24Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI2o, 
 Subscript[\[Lambda], 1] -> Subscript[k, "AI2,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI2,bb1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 4] -> spt, Subscript[K, 4] -> Subscript[k, "ET2,ST"] + 
       Subscript[k, st], Subscript[\[Lambda], 5] -> ss, Subscript[K, 5] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

{Subscript[q31A, AI3][t_], Subscript[q31A, bb1][t_], Subscript[q31A, 
BB1][t_], Subscript[q31A, ET2][t_], Subscript[q31A, ST][t_]} = 
   Table[Q[i], {i, 1, 5}] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], Subscript[K, 2] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 3] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + Subscript[k, st], 
     Subscript[K, 5] -> 0}; 

Subscript[q31B, B][t_] = Q[5] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], Subscript[K, 2] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 3] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 4] -> sp, Subscript[K, 4] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[K, 5] -> 0}; 

Subscript[q31C, B][t_] = Q[4] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], Subscript[K, 2] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 3] -> sp, 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[K, 4] -> 0}; 

Subscript[q31D, B][t_] = Q[3] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> sp, Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q31E, B][t_] = Q[2] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q31F, TH][t_], Subscript[q31F, B][t_]} = 
   Table[Q[i], {i, 2, 3}] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,TH"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> sp, Subscript[K, 2] -> Subscript[k, st], 
     Subscript[K, 3] -> 0}; 

{Subscript[q31At, AI3][t_], Subscript[q31At, bb1][t_], 
    Subscript[q31At, BB1][t_], Subscript[q31At, ET2][t_], 
    Subscript[q31At, ST][t_]} = Table[Q[i], {i, 2, 6}] /. 
    {Subscript[b, 1] -> AI3o, Subscript[\[Lambda], 1] -> spt, 
     Subscript[K, 1] -> Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "AI3,bb1"], 
     Subscript[K, 2] -> Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], Subscript[K, 5] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

Subscript[q31Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "AI3,bb1"], Subscript[K, 2] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + ss, Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], Subscript[K, 4] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> ss, 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q31Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "AI3,bb1"], Subscript[K, 2] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + ss, Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q31Dt, B][t_] = Q[4] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "AI3,bb1"], Subscript[K, 2] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[K, 4] -> 0}; 

Subscript[q31Et, B][t_] = Q[3] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> ss, 
     Subscript[K, 2] -> Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + ss, 
     Subscript[K, 3] -> 0}; 

{Subscript[q32At, bb1][t_], Subscript[q32At, BB1][t_], 
    Subscript[q32At, ET2][t_], Subscript[q32At, ST][t_]} = 
   Table[Q[i], {i, 3, 6}] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> spt, Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], Subscript[K, 4] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q32Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> spt, Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], Subscript[K, 4] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> ss, 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q32Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> spt, Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 3] -> Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q32Dt, B][t_] = Q[4] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> spt, Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[K, 4] -> 0}; 

{Subscript[q33At, BB1][t_], Subscript[q33At, ET2][t_], 
    Subscript[q33At, ST][t_]} = Table[Q[i], {i, 4, 6}] /. 
    {Subscript[b, 1] -> AI3o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "AI3,bb1"], Subscript[K, 1] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 4] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 5] -> Subscript[k, "ET2,ST"], Subscript[K, 5] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

Subscript[q33Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], Subscript[K, 2] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 3] -> spt, 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 4] -> Subscript[k, "BB1,ET2"], Subscript[K, 4] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 5] -> ss, 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 6] -> 0}; 

Subscript[q33Ct, B][t_] = Q[5] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], Subscript[K, 2] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 3] -> spt, 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 4] -> ss, Subscript[K, 4] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 5] -> 0}; 

{Subscript[q34At, ET2][t_], Subscript[q34At, ST][t_]} = 
   Table[Q[i], {i, 5, 6}] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], Subscript[K, 2] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 3] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 4] -> spt, Subscript[K, 4] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 5] -> 
      Subscript[k, "ET2,ST"], Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, 
      Subscript[\[Lambda], 6] -> 0, Subscript[K, 6] -> 0}; 

Subscript[q34Bt, B][t_] = Q[6] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,bb1"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], Subscript[K, 2] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 3] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 4] -> spt, Subscript[K, 4] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 5] -> ss, 
     Subscript[K, 5] -> Subscript[k, "ET2,ST"] + ss, Subscript[K, 6] -> 0}; 

{Subscript[q35At, TH][t_], Subscript[q35At, B][t_]} = 
   Table[Q[i], {i, 3, 4}] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "AI3,TH"], Subscript[K, 2] -> Subscript[k, "AI3,bb1"] + 
       Subscript[k, "AI3,TH"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> ss, Subscript[K, 4] -> 0}; 

{Subscript[q35Bt, TH][t_], Subscript[q35Bt, B][t_]} = 
   Table[Q[i], {i, 3, 4}] /. {Subscript[b, 1] -> AI3o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "AI3,TH"], Subscript[K, 1] -> 
      Subscript[k, "AI3,bb1"] + Subscript[k, "AI3,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> spt, Subscript[K, 2] -> Subscript[k, st], 
     Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> ss, 
     Subscript[K, 4] -> 0}; 

{Subscript[q41A, bb1][t_], Subscript[q41A, BB1][t_], Subscript[q41A, 
ET2][t_], Subscript[q41A, ST][t_]} = Table[Q[i], {i, 1, 4}] /. 
    {Subscript[b, 1] -> bb1o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 1] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "ET2,ST"], Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[K, 4] -> 0}; 

Subscript[q41B, B][t_] = Q[4] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb1,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> sp, Subscript[K, 3] -> 
      Subscript[k, st] + Subscript[k, "ET2,ST"], Subscript[K, 4] -> 0}; 

Subscript[q41C, B][t_] = Q[3] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb1,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[K, 3] -> 0}; 

Subscript[q41D, B][t_] = Q[2] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q41At, bb1][t_], Subscript[q41At, BB1][t_], 
    Subscript[q41At, ET2][t_], Subscript[q41At, ST][t_]} = 
   Table[Q[i], {i, 2, 5}] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q41Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, Subscript[K, 5] -> 0}; 

Subscript[q41Ct, B][t_] = Q[4] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb1,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb1,BB1"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 4] -> 0}; 

Subscript[q41Dt, B][t_] = Q[3] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
      Subscript[k, "bb1,BB1"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q42At, BB1][t_], Subscript[q42At, ET2][t_], 
    Subscript[q42At, ST][t_]} = Table[Q[i], {i, 3, 5}] /. 
    {Subscript[b, 1] -> bb1o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "bb1,BB1"], Subscript[K, 1] -> Subscript[k, "bb1,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> spt, Subscript[K, 2] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 3] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], Subscript[K, 4] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 5] -> 0}; 

Subscript[q42Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb1,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q42Ct, B][t_] = Q[4] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb1,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 4] -> 0}; 

{Subscript[q43At, ET2][t_], Subscript[q43At, ST][t_]} = 
   Table[Q[i], {i, 4, 5}] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb1,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 4] -> 
      Subscript[k, "ET2,ST"], Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
      Subscript[K, 5] -> 0}; 

Subscript[q43Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb1,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb1,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 5] -> 0}; 

{Subscript[q51A, bb2][t_], Subscript[q51A, BB1][t_], Subscript[q51A, 
ET2][t_], 
    Subscript[q51A, ST][t_]} = Table[Q[i], {i, 1, 4}] /. 
    {Subscript[b, 1]->bb2o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "bb2,BB1"], Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "ET2,ST"], Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[K, 4] -> 0}; 

Subscript[q51B, B][t_] = Q[4] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> sp, Subscript[K, 3] -> 
      Subscript[k, st] + Subscript[k, "ET2,ST"], Subscript[K, 4] -> 0}; 

Subscript[q51C, B][t_] = Q[3] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[K, 3] -> 0}; 

Subscript[q51D, B][t_] = Q[2] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q51At, bb2][t_], Subscript[q51At, BB1][t_], 
    Subscript[q51At, ET2][t_], Subscript[q51At, ST][t_]} = 
   Table[Q[i], {i, 2, 5}] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb2,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb2,BB1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q51Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb2,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb2,BB1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q51Ct, B][t_] = Q[4] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb2,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb2,BB1"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 4] -> 0}; 

Subscript[q51Dt, B][t_] = Q[3] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
      Subscript[k, "bb2,BB1"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q52At, BB1][t_], Subscript[q52At, ET2][t_], 
    Subscript[q52At, ST][t_]} = Table[Q[i], {i, 3, 5}] /. 
    {Subscript[b, 1] -> bb2o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "bb2,BB1"], Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> spt, Subscript[K, 2] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 3] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], Subscript[K, 4] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 5] -> 0}; 

Subscript[q52Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q52Ct, B][t_] = Q[4] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 4] -> 0}; 

{Subscript[q53At, ET2][t_], Subscript[q53At, ST][t_]} = 
   Table[Q[i], {i, 4, 5}] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 4] -> 
      Subscript[k, "ET2,ST"], Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
      Subscript[K, 5] -> 0}; 

Subscript[q53Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, Subscript[K, 5] -> 0}; 

{Subscript[q71A, BB1][t_], Subscript[q71A, ET2][t_], Subscript[q71A, ST][t_]} = 
   Table[Q[i], {i, 1, 3}] /. {Subscript[b, 1] -> BB1o, Subscript[\[Lambda], 1] -> Subscript[k, "BB1,ET2"], 
   Subscript[K, 1] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
   Subscript[\[Lambda], 2] -> Subscript[k, "ET2,ST"], Subscript[K, 2] -> Subscript[k, "ET2,ST"] + 
   Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q71B, B][t_] = Q[3] /. {Subscript[b, 1] -> BB1o, Subscript[\[Lambda], 1] -> Subscript[k, "BB1,ET2"], 
Subscript[K, 1] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
Subscript[K, 2] -> Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q71C, B][t_] = Q[2] /. {Subscript[b, 1] -> BB1o, 
Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "BB1,ET2"] + 
Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q71At, BB1][t_], Subscript[q71At, ET2][t_], Subscript[q71At, ST][t_]} = 
Table[Q[i], {i, 2, 4}] /. 
{Subscript[b, 1] -> BB1o, Subscript[\[Lambda], 1] -> spt, 
 Subscript[K, 1] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
Subscript[\[Lambda], 2] -> Subscript[k, "BB1,ET2"], Subscript[K, 2] -> 
Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 3] -> Subscript[k, "ET2,ST"], 
Subscript[K, 3] -> Subscript[k, "ET2,ST"] + ss, Subscript[K, 4] -> 0}; 
Subscript[q71Bt, B][t_] = Q[4] /. {Subscript[b, 1] -> BB1o, 
Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, 
"BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 4] -> 0}; 

Subscript[q71Ct, B][t_] = Q[3] /. {Subscript[b, 1] -> BB1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q51A, bb2][t_], Subscript[q51A, BB1][t_], Subscript[q51A, \
ET2][t_], 
    Subscript[q51A, ST][t_]} = Table[Q[i], {i, 1, 4}] /. 
    {Subscript[b, 1] -> bb2o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "bb2,BB1"], Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "ET2,ST"], Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[K, 4] -> 0}; 

Subscript[q51B, B][t_] = Q[4] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> sp, Subscript[K, 3] -> 
      Subscript[k, st] + Subscript[k, "ET2,ST"], Subscript[K, 4] -> 0}; 

Subscript[q51C, B][t_] = Q[3] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[K, 3] -> 0}; 

Subscript[q51D, B][t_] = Q[2] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q51At, bb2][t_], Subscript[q51At, BB1][t_], 
    Subscript[q51At, ET2][t_], Subscript[q51At, ST][t_]} = 
   Table[Q[i], {i, 2, 5}] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb2,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb2,BB1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, Subscript[K, 5] -> 0}; 

Subscript[q51Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb2,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb2,BB1"] + ss, 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, Subscript[K, 5] -> 0}; 

Subscript[q51Ct, B][t_] = Q[4] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "bb2,BB1"], 
     Subscript[K, 2] -> Subscript[k, "bb2,BB1"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, Subscript[K, 4] -> 0}; 

Subscript[q51Dt, B][t_] = Q[3] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
      Subscript[k, "bb2,BB1"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q52At, BB1][t_], Subscript[q52At, ET2][t_], 
    Subscript[q52At, ST][t_]} = Table[Q[i], {i, 3, 5}] /. 
    {Subscript[b, 1] -> bb2o, Subscript[\[Lambda], 1] -> 
      Subscript[k, "bb2,BB1"], Subscript[K, 1] -> Subscript[k, "bb2,BB1"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> spt, Subscript[K, 2] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 3] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[\[Lambda], 4] -> Subscript[k, "ET2,ST"], Subscript[K, 4] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 5] -> 0}; 

Subscript[q52Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "BB1,ET2"], Subscript[K, 3] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 5] -> 0}; 

Subscript[q52Ct, B][t_] = Q[4] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> Subscript[k, "BB1,ET2"] + ss, 
     Subscript[K, 4] -> 0}; 

{Subscript[q53At, ET2][t_], Subscript[q53At, ST][t_]} = 
   Table[Q[i], {i, 4, 5}] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 4] -> 
      Subscript[k, "ET2,ST"], Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
Subscript[K, 5] -> 0}; 

Subscript[q53Bt, B][t_] = Q[5] /. {Subscript[b, 1] -> bb2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bb2,BB1"], Subscript[K, 1] -> 
      Subscript[k, "bb2,BB1"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "BB1,ET2"], Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 3] -> spt, Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 4] -> ss, 
     Subscript[K, 4] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 5] -> 0}; 

{Subscript[q71A, BB1][t_], Subscript[q71A, ET2][t_], Subscript[q71A, ST][t_]}= 
Table[Q[i], {i, 1, 3}] /. {Subscript[b, 1] -> BB1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BB1,ET2"], Subscript[K, 1] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "ET2,ST"], Subscript[K, 2] -> Subscript[k, "ET2,ST"] + 
       Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q71B, B][t_] = Q[3] /. {Subscript[b, 1] -> BB1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BB1,ET2"], Subscript[K, 1] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
     Subscript[K, 2] -> Subscript[k, "ET2,ST"] + Subscript[k, st], 
     Subscript[K, 3] -> 0}; 

Subscript[q71C, B][t_] = Q[2] /. {Subscript[b, 1] -> BB1o, 
 Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, 
"BB1,ET2"] + Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q71At, BB1][t_], Subscript[q71At, ET2][t_], 
    Subscript[q71At, ST][t_]} = Table[Q[i], {i, 2, 4}] /. 
    {Subscript[b, 1] -> BB1o, Subscript[\[Lambda], 1] -> spt, 
     Subscript[K, 1] -> Subscript[k, "BB1,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "BB1,ET2"], Subscript[K, 2] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 3] -> Subscript[k, 
"ET2,ST"], Subscript[K, 3] -> Subscript[k, "ET2,ST"] + ss, 
 Subscript[K, 4] -> 0}; 

Subscript[q71Bt, B][t_] = Q[4] /. {Subscript[b, 1] -> BB1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "BB1,ET2"], 
     Subscript[K, 2] -> Subscript[k, "BB1,ET2"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 4] -> 0}; 

Subscript[q71Ct, B][t_] = Q[3] /. {Subscript[b, 1] -> BB1o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "BB1,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
      Subscript[k, "BB1,ET2"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q72At, ET2][t_], Subscript[q72At, ST][t_]} = 
   Table[Q[i], {i, 3, 4}] /. {Subscript[b, 1] -> BB1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BB1,ET2"], Subscript[K, 1] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "ET2,ST"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "ET2,ST"], Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 4] -> 0}; 

Subscript[q72Bt, B][t_] = Q[4] /. {Subscript[b, 1] -> BB1o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BB1,ET2"], Subscript[K, 1] -> 
      Subscript[k, "BB1,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "ET2,ST"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 4] -> 0}; 

{Subscript[q81A, BB2][t_], Subscript[q81A, ET2][t_], Subscript[q81A, ST][t_]} = 
   Table[Q[i], {i, 1, 3}] /. {Subscript[b, 1] -> BB2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BB2,ET2"], Subscript[K, 1] -> 
      Subscript[k, "BB2,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> 
      Subscript[k, "ET2,ST"], Subscript[K, 2] -> Subscript[k, "ET2,ST"] + 
       Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q81B, B][t_] = Q[3] /. {Subscript[b, 1] -> BB2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BB2,ET2"], Subscript[K, 1] -> 
      Subscript[k, "BB2,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
     Subscript[K, 2] -> Subscript[k, "ET2,ST"] + Subscript[k, st], 
     Subscript[K, 3] -> 0}; 

Subscript[q81C, B][t_] = Q[2] /. {Subscript[b, 1] -> BB2o, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "BB2,ET2"] + 
       Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q81At, BB2][t_], Subscript[q81At, ET2][t_], 
    Subscript[q81At, ST][t_]} = Table[Q[i], {i, 2, 4}] /. 
    {Subscript[b, 1] -> BB2o, Subscript[\[Lambda], 1] -> spt, 
     Subscript[K, 1] -> Subscript[k, "BB2,ET2"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "BB2,ET2"], Subscript[K, 2] -> 
      Subscript[k, "BB2,ET2"] + ss, Subscript[\[Lambda], 3] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 3] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 4] -> 0}; 

Subscript[q81Bt, B][t_] = Q[4] /. {Subscript[b, 1] -> BB2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "BB2,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "BB2,ET2"], 
     Subscript[K, 2] -> Subscript[k, "BB2,ET2"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 4] -> 0}; 

Subscript[q81Ct, B][t_] = Q[3] /. {Subscript[b, 1] -> BB2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "BB2,ET2"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
      Subscript[k, "BB2,ET2"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q82At, ET2][t_], Subscript[q82At, ST][t_]} = 
   Table[Q[i], {i, 3, 4}] /. {Subscript[b, 1] -> BB2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BB2,ET2"], Subscript[K, 1] -> 
      Subscript[k, "BB2,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "ET2,ST"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> Subscript[k, "ET2,ST"], Subscript[K, 3] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 4] -> 0}; 

Subscript[q82Bt, B][t_] = Q[4] /. {Subscript[b, 1] -> BB2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BB2,ET2"], Subscript[K, 1] -> 
      Subscript[k, "BB2,ET2"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, "ET2,ST"] + Subscript[k, st], 
     Subscript[\[Lambda], 3] -> ss, Subscript[K, 3] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 4] -> 0}; 

{Subscript[q91A, BBseq][t_], Subscript[q91A, TH][t_], Subscript[q91A, B][t_]} = 
   Table[Q[i], {i, 1, 3}] /. {Subscript[b, 1] -> BBseqo, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BBseq,TH"], Subscript[K, 1] -> 
      Subscript[k, "BBseq,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
     Subscript[K, 2] -> Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q91B, B][t_] = Q[2] /. {Subscript[b, 1] -> BBseqo, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "BBseq,TH"] + 
       Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q91At, BBseq][t_], Subscript[q91At, TH][t_], 
    Subscript[q91At, B][t_]} = Table[Q[i], {i, 2, 4}] /. 
    {Subscript[b, 1] -> BBseqo, Subscript[\[Lambda], 1] -> spt, 
     Subscript[K, 1] -> Subscript[k, "BBseq,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "BBseq,TH"], Subscript[K, 2] -> 
      Subscript[k, "BBseq,TH"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> ss, Subscript[K, 4] -> 0}; 

{Subscript[q91Bt, TH][t_], Subscript[q91Bt, B][t_]} = 
   Table[Q[i], {i, 3, 4}] /. {Subscript[b, 1] -> BBseqo, 
     Subscript[\[Lambda], 1] -> Subscript[k, "BBseq,TH"], Subscript[K, 1] -> 
      Subscript[k, "BBseq,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, st], Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> ss, Subscript[K, 4] -> 0}; 

{Subscript[q61A, bbseq][t_], Subscript[q61A, TH][t_], Subscript[q61A, B][t_]} = Table[Q[i], 
{i, 1, 3}] /. {Subscript[b, 1] -> bbseqo, 
 Subscript[\[Lambda], 1] -> Subscript[k, "bbseq,TH"], Subscript[K, 1] -> 
Subscript[k, "bbseq,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> sp, 
 Subscript[K, 2] -> Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q61B, B][t_] = Q[2] /. {Subscript[b, 1] -> bbseqo, 
Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "bbseq,TH"] + 
Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q61At, bbseq][t_], Subscript[q61At, TH][t_], 
    Subscript[q61At, B][t_]} = Table[Q[i], {i, 2, 4}] /. 
    {Subscript[b, 1] -> bbseqo, Subscript[\[Lambda], 1] -> spt, 
     Subscript[K, 1] -> Subscript[k, "bbseq,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "bbseq,TH"], Subscript[K, 2] -> 
      Subscript[k, "bbseq,TH"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> ss, Subscript[K, 4] -> 0}; 

{Subscript[q61Bt, TH][t_], Subscript[q61Bt, B][t_]} = 
   Table[Q[i], {i, 3, 4}] /. {Subscript[b, 1] -> bbseqo, 
     Subscript[\[Lambda], 1] -> Subscript[k, "bbseq,TH"], Subscript[K, 1] -> 
      Subscript[k, "bbseq,TH"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, st], Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> ss, Subscript[K, 4] -> 0}; 

{Subscript[q111A, ET2][t_], Subscript[q111A, ST][t_]} = 
   Table[Q[i], {i, 1, 2}] /. {Subscript[b, 1] -> ET2o, 
     Subscript[\[Lambda], 1] -> Subscript[k, "ET2,ST"], Subscript[K, 1] -> 
      Subscript[k, "ET2,ST"] + Subscript[k, st], Subscript[K, 2] -> 0}; 

Subscript[q111B, B][t_] = Q[2] /. {Subscript[b, 1] -> ET2o, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "ET2,ST"] 
+ Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q111At, ET2][t_], Subscript[q111At, ST][t_]} = 
   Table[Q[i], {i, 2, 3}] /. {Subscript[b, 1] -> ET2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "ET2,ST"] + 
       Subscript[k, st], Subscript[\[Lambda], 2] -> Subscript[k, "ET2,ST"], 
     Subscript[K, 2] -> Subscript[k, "ET2,ST"] + ss, 
     Subscript[K, 3] -> 0}; 

Subscript[q111Bt, B][t_] = Q[3] /. {Subscript[b, 1] -> ET2o, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, 
"ET2,ST"] + Subscript[k, st], Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> 
      Subscript[k, "ET2,ST"] + ss, Subscript[K, 3] -> 0}; 

{Subscript[q121A, ETseq][t_], Subscript[q121A, ET][t_], 
    Subscript[q121A, B][t_]} = Table[Q[i], {i, 1, 3}] /. 
    {Subscript[b, 1] -> ETseqo, Subscript[\[Lambda], 1] -> 
      Subscript[k, "ETseq,ET"], Subscript[K, 1] -> Subscript[k, "ETseq,ET"] + 
     Subscript[k, st], Subscript[\[Lambda], 2] -> sp, Subscript[K, 2] -> 
      Subscript[k, st], Subscript[K, 3] -> 0}; 

Subscript[q121B, B][t_] = Q[2] /. {Subscript[b, 1] -> ETseqo, 
     Subscript[\[Lambda], 1] -> sp, Subscript[K, 1] -> Subscript[k, "ETseq,ET"] + 
       Subscript[k, st], Subscript[K, 2] -> 0}; 

{Subscript[q121At, ETseq][t_], Subscript[q121At, ET][t_], 
    Subscript[q121At, B][t_]} = Table[Q[i], {i, 2, 4}] /. 
    {Subscript[b, 1] -> ETseqo, Subscript[\[Lambda], 1] -> spt, 
     Subscript[K, 1] -> Subscript[k, "ETseq,ET"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> Subscript[k, "ETseq,ET"], Subscript[K, 2] -> 
      Subscript[k, "ETseq,ET"] + ss, Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> ss, Subscript[K, 4] -> 0}; 

{Subscript[q121Bt, ET][t_], Subscript[q121Bt, B][t_]} = 
   Table[Q[i], {i, 3, 4}] /. {Subscript[b, 1] -> ETseqo, 
     Subscript[\[Lambda], 1] -> Subscript[k, "ETseq,ET"], Subscript[K, 1] -> 
      Subscript[k, "ETseq,ET"] + Subscript[k, st], Subscript[\[Lambda], 2] -> spt, 
     Subscript[K, 2] -> Subscript[k, st], Subscript[\[Lambda], 3] -> ss, 
     Subscript[K, 3] -> ss, Subscript[K, 4] -> 0}; 

(*Added: 23-02-2004*)

Subscript[q91Ct, B][t_] = Q[3] /. {Subscript[b, 1] -> BBseqo, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, 
"BBseq,TH"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> Subscript[k, 
"BBseq,TH"] + ss, Subscript[K, 3] -> 0}; 

Subscript[q61Ct, B][t_] = Q[3] /. {Subscript[b, 1] -> bbseqo, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "bbseq,TH"] + 
     Subscript[k, st],  Subscript[\[Lambda], 2] -> ss, 
     Subscript[K, 2] -> Subscript[k, "bbseq,TH"] + ss, Subscript[K, 3] -> 0}; 

Subscript[q121Ct, B][t_] = Q[3] /. {Subscript[b, 1] -> ETseqo, 
     Subscript[\[Lambda], 1] -> spt, Subscript[K, 1] -> Subscript[k, "ETseq,ET"] + Subscript[k, st], 
     Subscript[\[Lambda], 2] -> ss, Subscript[K, 2] -> Subscript[k, 
"ETseq,ET"] + ss, Subscript[K, 3] -> 0}; 

(*End Added*)

qAI1[t_] := Subscript[q11A, AI1][t] + Subscript[q11At, AI1][t]

qAI2[t_] := Subscript[q21A, AI2][t] + Subscript[q21At, AI2][t]

qAI3[t_] := Subscript[q31A, AI3][t] + Subscript[q31At, AI3][t]

qbb1[t_] := Subscript[q11A, bb1][t] + Subscript[q11At, bb1][t] + 
Subscript[q12At, bb1][t] + Subscript[q21A, bb1][t] + Subscript[q21At, bb1][t] + 
Subscript[q22At, bb1][t] + Subscript[q31A, bb1][t] + Subscript[q31At, bb1][t] + 
Subscript[q32At, bb1][t] + Subscript[q41A, bb1][t] + Subscript[q41At, bb1][t]

qbbseq[t_] := Subscript[q61A, bbseq][t] + Subscript[q61At, bbseq][t]

qbb2[t_] := Subscript[q51A, bb2][t] + Subscript[q51At, bb2][t]

qBB1[t_] := Subscript[q11A, BB1][t] + Subscript[q11At, BB1][t] + 
Subscript[q12At, BB1][t] + Subscript[q13At, BB1][t] + Subscript[q21A, BB1][t] + 
Subscript[q21At, BB1][t] + Subscript[q22At, BB1][t] + Subscript[q23At, BB1][t] + 
Subscript[q31A, BB1][t] + Subscript[q31At, BB1][t] + Subscript[q32At, BB1][t] + 
Subscript[q33At, BB1][t] + Subscript[q41A, BB1][t] + Subscript[q41At, BB1][t] + 
Subscript[q42At, BB1][t] + Subscript[q51A, BB1][t] + Subscript[q51At, BB1][t] + 
Subscript[q52At, BB1][t] + Subscript[q71A, BB1][t] + Subscript[q71At, BB1][t]

qBBseq[t_] := Subscript[q91A, BBseq][t] + Subscript[q91At, BBseq][t]

qBB2[t_] := Subscript[q81A, BB2][t] + Subscript[q81At, BB2][t]

qTH[t_] := Subscript[q31F, TH][t] + Subscript[q35At,TH][t] + Subscript[q35Bt, TH][t] + 
Subscript[q91A, TH][t] + Subscript[q91At, TH][t] + Subscript[q91Bt, TH][t] + 
Subscript[q61A, TH][t] + Subscript[q61At, TH][t] + Subscript[q61Bt, TH][t]

qET2[t_] := Subscript[q11A, ET2][t] + Subscript[q11At, ET2][t] + Subscript[q12At, ET2][t] + 
Subscript[q13At, ET2][t] + Subscript[q14At, ET2][t] + Subscript[q21A, ET2][t] + 
Subscript[q21At, ET2][t] + Subscript[q22At, ET2][t] + Subscript[q23At, ET2][t] + 
Subscript[q24At, ET2][t] + Subscript[q31A, ET2][t] + Subscript[q31At, ET2][t] +
Subscript[q32At, ET2][t] + Subscript[q33At, ET2][t] + Subscript[q34At, ET2][t] + 
Subscript[q41A, ET2][t] + Subscript[q41At, ET2][t] + Subscript[q42At, ET2][t] + 
Subscript[q43At, ET2][t] + Subscript[q51A, ET2][t] + Subscript[q51At, ET2][t] + 
Subscript[q52At, ET2][t] + Subscript[q53At, ET2][t] + Subscript[q71A, ET2][t] + 
Subscript[q71At, ET2][t] + Subscript[q72At, ET2][t] + Subscript[q81A, ET2][t] + 
Subscript[q81At, ET2][t] + Subscript[q82At, ET2][t] + Subscript[q111A, ET2][t] + 
Subscript[q111At, ET2][t]

qETseq[t_] := Subscript[q121A,ETseq][t]+Subscript[q121At, ETseq][t]

(*LNet*)
qET[t_] := Subscript[q121A, ET][t] +Subscript[q121At, ET][t] + Subscript[q121Bt, ET][t]

(*Con compartimentos trasformados*)

qBDiret[t_] := Subscript[q11B, B][t] + Subscript[q11C, B][t] + Subscript[q11D, B][t] + 
   Subscript[q11E, B][t] + Subscript[q21B, B][t] + Subscript[q21C, B][t] + 
   Subscript[q21D, B][t] + Subscript[q21E, B][t] + Subscript[q31B, B][t] + 
   Subscript[q31C, B][t] + Subscript[q31D, B][t] + Subscript[q31E, B][t] + 
   Subscript[q31F, B][t] + Subscript[q41B, B][t] + Subscript[q41C, B][t] + 
   Subscript[q41D, B][t] + Subscript[q51B, B][t] + Subscript[q51C, B][t] + 
   Subscript[q51D, B][t] + Subscript[q71B, B][t] + Subscript[q71C, B][t] + 
   Subscript[q81B, B][t] + Subscript[q81C, B][t] + Subscript[q91A, B][t] + 
   Subscript[q91B, B][t] + Subscript[q61A, B][t] + Subscript[q61B, B][t] + 
   Subscript[q111B, B][t] + Subscript[q121A, B][t] + Subscript[q121B, B][t] + 
   Subscript[q11Bt, B][t] + Subscript[q11Ct, B][t] + Subscript[q11Dt, B][t] + 
   Subscript[q11Et, B][t] + Subscript[q12Bt, B][t] + Subscript[q12Ct, B][t] + 
   Subscript[q12Dt, B][t] + Subscript[q13Bt, B][t] + Subscript[q13Ct, B][t] + 
   Subscript[q14Bt, B][t] + Subscript[q21Bt, B][t] + Subscript[q21Ct, B][t] + 
   Subscript[q21Dt, B][t] + Subscript[q21Et, B][t] + Subscript[q22Bt, B][t] + 
   Subscript[q22Ct, B][t] + Subscript[q22Dt, B][t] + 
   Subscript[q23Bt, B][t] + Subscript[q23Ct, B][t] + Subscript[q24Bt, B][t] + 
   Subscript[q31Bt, B][t] + Subscript[q31Ct, B][t] + Subscript[q31Dt, B][t] + 
   Subscript[q31Et, B][t] + Subscript[q32Bt, B][t] + Subscript[q32Ct, B][t] + 
   Subscript[q32Dt, B][t] + Subscript[q33Bt, B][t] + Subscript[q33Ct, B][t] + 
   Subscript[q34Bt, B][t] + Subscript[q35At, B][t] + Subscript[q35Bt, B][t] + 
   Subscript[q41Bt, B][t] + Subscript[q41Ct, B][t] + Subscript[q41Dt, B][t] + 
   Subscript[q42Bt, B][t] + Subscript[q42Ct, B][t] + Subscript[q43Bt, B][t] + 
   Subscript[q51Bt, B][t] + Subscript[q51Ct, B][t] + Subscript[q51Dt, B][t] + 
   Subscript[q52Bt, B][t] + Subscript[q52Ct, B][t] + Subscript[q53Bt, B][t] + 
   Subscript[q71Bt, B][t] + Subscript[q71Ct, B][t] + Subscript[q72Bt, B][t] + 
   Subscript[q81Bt, B][t] + Subscript[q81Ct, B][t] + Subscript[q82Bt, B][t] + 
   Subscript[q91At, B][t] + Subscript[q91Bt, B][t] + Subscript[q61At, B][t] + 
   Subscript[q61Bt, B][t] + Subscript[q111Bt, B][t] + Subscript[q121At, B][t] + 
   Subscript[q121Bt, B][t] + Subscript[q91Ct, B][t] + Subscript[q61Ct, B][t]+ 
   Subscript[q121Ct, B][t];

(*Sin compartimentos trasformados*)
qBDiretNoT[t_] := Subscript[q11B, B][t] + Subscript[q11C, B][t] + Subscript[q11D, B][t] + 
   Subscript[q11E, B][t] + Subscript[q21B, B][t] + Subscript[q21C, B][t] + 
   Subscript[q21D, B][t] + Subscript[q21E, B][t] + Subscript[q31B, B][t] + 
   Subscript[q31C, B][t] + Subscript[q31D, B][t] + Subscript[q31E, B][t] + 
   Subscript[q31F, B][t] + Subscript[q41B, B][t] + Subscript[q41C, B][t] + 
   Subscript[q41D, B][t] + Subscript[q51B, B][t] + Subscript[q51C, B][t] + 
   Subscript[q51D, B][t] + Subscript[q71B, B][t] + Subscript[q71C, B][t] + 
   Subscript[q81B, B][t] + Subscript[q81C, B][t] + Subscript[q91A, B][t] + 
   Subscript[q91B, B][t] + Subscript[q61A, B][t] + Subscript[q61B, B][t]+ 
   Subscript[q111B, B][t] + Subscript[q121A, B][t] + Subscript[q121B, B][t];
   
qSt[t_] := Subscript[q11A, ST][t] + Subscript[q11At, ST][t] + 
    Subscript[q12At, ST][t] + Subscript[q13At, ST][t] + 
    Subscript[q14At, ST][t] + Subscript[q21A, ST][t] + 
    Subscript[q21At, ST][t] + Subscript[q22At, ST][t] + 
    Subscript[q23At, ST][t] + Subscript[q24At, ST][t] + 
    Subscript[q31A, ST][t] + Subscript[q31At, ST][t] + 
    Subscript[q32At, ST][t] + Subscript[q33At, ST][t] + 
    Subscript[q34At, ST][t] + Subscript[q41A, ST][t] + 
    Subscript[q41At, ST][t] + Subscript[q42At, ST][t] + 
    Subscript[q43At, ST][t] + Subscript[q51A, ST][t] + 
    Subscript[q51At, ST][t] + Subscript[q52At, ST][t] + 
    Subscript[q53At, ST][t] + Subscript[q71A, ST][t] + 
    Subscript[q71At, ST][t] + Subscript[q72At, ST][t] + 
    Subscript[q81A, ST][t] + Subscript[q81At, ST][t] + 
    Subscript[q82At, ST][t] + Subscript[q111A, ST][t] + 
    Subscript[q111At, ST][t]; 

Subscript[k, st] = sp + spt; 

(*Default absortion parameters Type F, M and S. ICRP 66. Table 18*)

F = {100, 0, 0};
M = {10, 90, 0.005};
S = {0.1, 100, 0.0001};


(*Default values for regional deposition {AI, bbfastseq, bbslowreg, BBfastseqreg, BBslowreg, 
ET2reg, ET1reg}for reference workers as function of AMAD. ICRP 66. Table F1 and CDROM*)

(*MODIFIED in ver 1.2*)

{AMAD0001, AMAD0003, AMAD001, AMAD003, AMAD01, AMAD03, AMAD05, AMAD07, AMAD1, 
    AMAD2, AMAD3, AMAD4, AMAD5, AMAD7, AMAD10, AMAD15, AMAD20} = 
   Transpose[{{0.000453, 0.022382, 0.27432, 0.50845, 0.28964, 0.1486, 0.12, 
      0.11, 0.1066, 0.0922, 0.077122, 0.06395, 0.053189, 0.038, 0.023682, 
      0.012, 0.0072}, {0.0229412, 0.088945, 0.130933, 0.072901, 0.0337526, 
      0.0154462, 0.011, 0.0094, 0.0084427, 0.00798, 0.00767541, 0.00722, 
      0.00664621, 0.0055, 0.00417492, 0.0027, 0.0018}, 
     {0.02294, 0.08895, 0.1309, 0.0729, 0.03376, 0.01544, 0.011, 0.0092, 
      0.008087, 0.00681, 0.005954, 0.005099, 0.004384, 0.0032, 0.002099, 
      0.0011, 0.00066}, {0.0316125, 0.0448276, 0.0272312, 0.0104969, 
      0.00481338, 0.00330619, 0.004, 0.0051, 0.00657594, 0.00996, 0.0114008, 
      0.01194, 0.0118343, 0.011, 0.00952448, 0.0072, 0.0055}, 
     {0.03161, 0.04483, 0.02723, 0.01049, 0.004813, 0.003293, 0.0039, 0.0048, 
      0.005844, 0.00737, 0.00729, 0.006626, 0.005921, 0.0046, 0.003116, 
      0.0018, 0.0011}, {0.439, 0.3494, 0.1735, 0.06994, 0.03218, 0.0582, 
      0.11, 0.15, 0.2111, 0.322, 0.3699, 0.391, 0.3989, 0.4, 0.3836, 0.36, 
      0.33}, {0.4435196, 0.3328748, 0.1539868, 0.06251499, 0.0307261, 
      0.05219912, 0.089, 0.12, 0.1653056, 0.254, 0.300285, 0.3249, 0.3386996, 
      0.35, 0.3472919, 0.33, 0.32}}]; 

AMADAdultW[(x_)?NumericQ] := Module[{diam, ai, bbfseq, bbs, BBfseq, BBs, 
      et2, et1}, diam = {0.001, 0.003, 0.01, 0.03, 0.1, 0.3, 0.5, 0.7, 1, 
        1.5, 2, 3, 4, 5, 7, 10, 15, 20}; {ai, bbfseq, bbs, BBfseq, BBs, et2, 
        et1} = Transpose[{AMAD0001, AMAD0003, AMAD001, AMAD003, AMAD01, 
         AMAD03, AMAD05, AMAD07, AMAD1, {0.09948, 0.00817375, 0.00740375, 
          0.00851625, 0.00679, 0.27445, 0.21495}, AMAD2, AMAD3, AMAD4, AMAD5, 
         AMAD7, AMAD10, AMAD15, AMAD20}]; 
      (Interpolation[Transpose[{diam, #1}], InterpolationOrder -> 3][
         x] & ) /@ {ai, bbfseq, bbs, BBfseq, BBs, et2, et1}] /; 
    0.001 <= x <= 20; 

AMADAdultW[x_] := "The AMAD x must be a number in interval 0.001 - 20 "; 

(* Added 1.2*)

AMADyr1[x_] /; NumericQ[x] && 0.001 <= x <= 10 := 
   (Interpolation[Transpose[{{0.001, 0.003, 0.01, 
           0.03, 0.1, 0.3, 1, 3, 5, 10}, #1}], 
        InterpolationOrder -> 3][x] & ) /@ 
     {{0.00001132, 0.0032332, 0.1345, 0.41422, 
       0.31718, 0.17082, 0.096366, 0.053134, 
       0.033286, 0.01329}, {0.00631034, 
       0.0519473, 0.144726, 0.095101, 0.0455274, 
       0.0212475, 0.0086075, 0.00460054, 
       0.00340029, 0.00187555}, {0.00631, 
       0.05195, 0.1447, 0.0951, 0.04553, 0.02125, 
       0.008462, 0.003906, 0.002497, 0.00106}, 
      {0.0373834, 0.072749, 0.0559533, 0.0218358, 
       0.0097647, 0.00554863, 0.00539287, 
       0.00677729, 0.00656398, 0.0049823}, 
      {0.03739, 0.07275, 0.05595, 0.02184, 
       0.009765, 0.005542, 0.005018, 0.004693, 
       0.003576, 0.001775}, {0.45, 0.3674, 
       0.1902, 0.07379, 0.03444, 0.08744, 0.2729, 
       0.4132, 0.4255, 0.3935}, {0.4568251, 
       0.3540838, 0.16939515, 0.06607692, 
       0.03298723, 0.07363374, 0.2108365, 
       0.3423067, 0.3709129, 0.3649969}} /; 
    0.001 <= x <= 10; 

AMADyr1[x_] := "The AMAD x must be a number in interval 0.001 - 10 "; 

AMADyr10[x_] /; NumericQ[x] && 0.001 <= x <= 10 := 
   (Interpolation[Transpose[{{0.001, 0.003, 0.01, 
           0.03, 0.1, 0.3, 1, 3, 5, 10}, #1}], 
        InterpolationOrder -> 3][x] & ) /@ 
     {{0.00030782, 0.01654, 0.23018, 0.45822, 0.26718, 
   0.1371, 0.095133, 0.067567, 0.046667, 
   0.020986}, {0.0175761, 0.077201, 0.132353, 
   0.078996, 0.0372921, 0.0170893, 0.0086771, 
   0.00731893, 0.00629887, 0.0040037}, 
  {0.01758, 0.0772, 0.1323, 0.079, 0.03729, 
   0.01709, 0.008343, 0.005671, 0.004111, 
   0.001953}, {0.0328093, 0.0511461, 0.0336004, 
   0.0131947, 0.00606491, 0.00389242, 0.00612969, 
   0.0096296, 0.0098209, 0.00783294}, 
  {0.0328, 0.05115, 0.0336, 0.01319, 0.006065, 
   0.003882, 0.005541, 0.006311, 0.005019, 
   0.002587}, {0.4426, 0.3553, 0.1789, 0.07234, 
   0.03378, 0.06755, 0.2285, 0.3797, 0.4039, 
   0.3848}, {0.4479214, 0.3397778, 0.1589895, 
   0.06458619, 0.0322569, 0.05897379, 0.1776143, 
   0.30999, 0.3455021, 0.3505925}} /; 
    0.001 <= x <= 10; 

AMADyr10[x_] := "The AMAD x must be a number in interval 0.001 - 10 "; 

AMADAdultP[x_] /; NumericQ[x] && 0.001 <= x <= 10 := 
   (Interpolation[Transpose[{{0.001, 0.003, 0.01, 
           0.03, 0.1, 0.3, 1, 3, 5, 10}, #1}], 
        InterpolationOrder -> 3][x] & ) /@ 
     {{0.00053089, 0.020264, 0.25118, 0.48911, 0.28618, 
   0.1498, 0.1148, 0.090034, 0.064566, 0.03035}, 
  {0.0214097, 0.084452, 0.134482, 0.077698, 
   0.0364199, 0.0169371, 0.0100156, 0.0101236, 
   0.0091488, 0.0060751}, {0.02141, 0.08445, 
   0.1345, 0.0777, 0.03642, 0.01693, 0.009494, 
   0.007532, 0.005681, 0.002797}, 
  {0.0324746, 0.04786, 0.0302332, 0.0117039, 
   0.00536511, 0.00354857, 0.00688602, 0.012965, 
   0.0140334, 0.0118375}, {0.03247, 0.04786, 
   0.03023, 0.0117, 0.005365, 0.003533, 0.005974, 
   0.007749, 0.006455, 0.00351}, 
  {0.4445, 0.354, 0.1767, 0.07105, 0.03242, 
   0.05208, 0.1896, 0.3478, 0.3834, 0.3785}, 
  {0.4389224, 0.3318771, 0.1546884, 0.06257555, 
   0.03038622, 0.04698606, 0.14899485, 0.279274, 
   0.3194918, 0.3330894}} /; 
    0.001 <= x <= 10; 

AMADAdultP[x_] := "The AMAD x must be a number in interval 0.001 - 10 "; 
(*Fit function that give the regional depositions {AI, bbfastseq, bbslowreg, BBfastseqreg, 
BBslowreg, ET2reg, ET1reg} for reference workers as function of AMAD. *)

(*Added in v 1.1*)
AMADfit[x1_] := {0.12818684263349484/E^(0.17011061305604133*x1), 
0.01007371130196758/
      E^(0.08789446045802779*x1), 
0.02128439252974103/E^(4.353270952537328*x1) + 
      0.00920990952521698/E^(0.14724386061421538*x1), 
-0.017173801702648556/E^(0.5667829354923091*x1) + 
      0.017173801702648556/E^(0.05778349162703789*x1), 
-0.011083919295381033/E^(1.1114709327884795*x1) + 
      0.011083919295381033/E^(0.1235776148578769*x1), 
-0.45501050673600746/E^(0.6369957209150685*x1) + 
      0.45501050673600746/E^(0.016181573219851104*x1), 
-0.3771412501157258/E^(0.5790115176890123*x1) + 
      0.3771412501157258/E^(0.008303685530885424*x1)} /; 0.5 <= x1 <= 20 || 
NumericQ[x1] === False; 
AMADfit[x1_] := {0.12818684263349484/E^(0.17011061305604133*x1), 
0.01007371130196758/
      E^(0.08789446045802779*x1), 
0.02128439252974103/E^(4.353270952537328*x1) + 
      0.00920990952521698/E^(0.14724386061421538*x1), 
-0.017173801702648556/E^(0.5667829354923091*x1) + 
      0.017173801702648556/E^(0.05778349162703789*x1), 
-0.011083919295381033/E^(1.1114709327884795*x1) + 
      0.011083919295381033/E^(0.1235776148578769*x1), 
-0.45501050673600746/E^(0.6369957209150685*x1) + 
      0.45501050673600746/E^(0.016181573219851104*x1), 
-0.3771412501157258/E^(0.5790115176890123*x1) + 
      0.3771412501157258/E^(0.008303685530885424*x1)} /; Symbol[x1] === False; 
AMADfit[x1_] := "AMAD must be in interval 0.5 - 20 or to be a Symbol"; 

qRespTract[int_, {AIreg_, bbfastseqreg_, bbslowreg_, BBfastseqreg_, BBslowreg_, 
ET2reg_, ET1reg_}, {SP_, SPT_, SS_}, t_, lambda_, opts___Rule] := 
Module[{a, qet1, t1, ai}, ai = AIreg; {AI1o = fAI1*ai, AI2o = fAI2*ai, 
AI3o = fAI3*ai, bb1o=(1-fbs)*bbfastseqreg-fbs*bbslowreg, bb2o=bbslowreg,
bbseqo=fbs*(bbfastseqreg+bbslowreg), BB1o=(1-fBs)*BBfastseqreg-fBs*BBslowreg,
BB2o=BBslowreg, BBseqo=fBs*(BBfastseqreg+BBslowreg), ET2o = fet2 ET2reg, 
ETseqo = (1-fet2) ET2reg}/. {opts} /. Options[qRespTract];
qet1[t1_]= ET1reg Exp[- Subscript[k,Env] t1]; 
a = {qet1[t],qAI1[t], qAI2[t], qAI3[t], qbb1[t], qbb2[t], qbbseq[t], qBB1[t], 
qBB2[t], qBBseq[t], qTH[t], qET2[t], qETseq[t], qET[t]} /. {sp -> SP, 
spt -> SPT, ss -> SS} /. {opts} /. Options[qRespTract];  
Thread[Flatten[{qET1[t],Table[Subscript[q, i][t], 
{i, 1, 13}]}] -> ExpandAll[int*a*Exp[(-lambda)*t]]]]; 

qRT2[int_, amad_, sol_, t1_, (lambda_)?NumericQ, opts___Rule] := 
Module[{a, x1, t, t2}, 
a = {qET1[t], Subscript[q, 1][t] + Subscript[q, 2][t] + 
 Subscript[q, 3][t], Subscript[q, 4][t], Subscript[q, 5][t], 
 Subscript[q, 6][t], Subscript[q, 7][t], Subscript[q, 8][t], 
 Subscript[q, 9][t], Subscript[q, 10][t], Subscript[q, 11][t], 
 Subscript[q, 12][t], Subscript[q, 13][t]} /. qRespTract[1, amad, sol, t, lambda, opts]; 
 x1[t2_] = a /. t -> t2; Thread[{Subscript[q, ET1][t1], Subscript[q, AI][t1], 
 Subscript[q, bb1][t1], Subscript[q, bb2][t1], Subscript[q, bbseq][t1], 
 Subscript[q, BB1][t1], Subscript[q, BB2][t1], 
 Subscript[q, BBseq][t1], Subscript[q, LNth][t1], 
 Subscript[q, ET2][t1], Subscript[q, ETseq][t1], 
 Subscript[q, LNet][t1]} -> Flatten[x1[t1]]]]; 

qRTContinuous[{int_, t3_}, amad_, sol_, t1_, (lambda_)?NumericQ, 
    opts___Rule] := Module[{a, x1, t, t2}, 
    a = {qET1[t], Subscript[q, 1][t] + Subscript[q, 2][t] + 
         Subscript[q, 3][t], Subscript[q, 4][t], Subscript[q, 5][t], 
        Subscript[q, 6][t], Subscript[q, 7][t], Subscript[q, 8][t], 
        Subscript[q, 9][t], Subscript[q, 10][t], Subscript[q, 11][t], 
        Subscript[q, 12][t], Subscript[q, 13][t]} /. qRespTract[1, amad, sol, t, lambda, opts]; x1[t2_] = a /. t -> t2; 
     Thread[{Subscript[q, ET1][t1], Subscript[q, AI][t1], 
        Subscript[q, bb1][t1], Subscript[q, bb2][t1], Subscript[q, bbseq][
         t1], Subscript[q, BB1][t1], Subscript[q, BB2][t1], 
        Subscript[q, BBseq][t1], Subscript[q, LNth][t1], 
        Subscript[q, ET2][t1], Subscript[q, ETseq][t1], 
        Subscript[q, LNet][t1]} -> Flatten[
        (qContinuousRT[int, {#1}, t3, t1] & ) /@ x1[t3]]]]; 

qRTChronic[int_, amad_, sol_, t1_, (lambda_)?NumericQ, opts___Rule] := 
   Module[{a, x1, t, t2}, 
    a = {qET1[t], Subscript[q, 1][t] + Subscript[q, 2][t] + 
         Subscript[q, 3][t], Subscript[q, 4][t], Subscript[q, 5][t], 
        Subscript[q, 6][t], Subscript[q, 7][t], Subscript[q, 8][t], 
        Subscript[q, 9][t], Subscript[q, 10][t], Subscript[q, 11][t], 
        Subscript[q, 12][t], Subscript[q, 13][t]} /. qRespTract[1, amad, sol, t, lambda, opts]; x1[t2_] = a /. t -> t2; 
     Thread[{Subscript[q, ET1][t1], Subscript[q, AI][t1], 
        Subscript[q, bb1][t1], Subscript[q, bb2][t1], Subscript[q, bbseq][
         t1], Subscript[q, BB1][t1], Subscript[q, BB2][t1], 
        Subscript[q, BBseq][t1], Subscript[q, LNth][t1], 
        Subscript[q, ET2][t1], Subscript[q, ETseq][t1], 
        Subscript[q, LNet][t1]} -> Flatten[
        (qContinuousRT[int, {#1}, t, t1] & ) /@ x1[t]]]]; 

RespiratoryTract["Acute", int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
  qRT2[int, ifd, fra, t, lambda, opts];

RespiratoryTract["Constant", int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
  qRTChronic[int, ifd, fra, t, lambda, opts];

RespiratoryTract["Continuous", int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
qRTContinuous[int, ifd, fra, t, lambda, opts];

RespiratoryTract[int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
  Module[{meth}, meth = IntakeType /. {opts} /. Options[RespiratoryTract]; 
   RespiratoryTract[meth, int, ifd, fra, t, lambda, opts]];

qLungs[int_, {AIreg_, bbfastseqreg_, bbslowreg_, BBfastseqreg_, BBslowreg_, 
ET2reg_, ET1reg_}, 
    {SP_, SPT_, SS_}, t_, lambda_, opts___Rule] := Module[{ai}, ai = AIreg; 
{AI1o = fAI1*ai, 
    AI2o = fAI2*ai, AI3o = fAI3*ai, bb1o=(1-fbs)*bbfastseqreg-fbs*bbslowreg, 
bb2o=bbslowreg,
  bbseqo=fbs*(bbfastseqreg+bbslowreg), 
BB1o=(1-fBs)*BBfastseqreg-fBs*BBslowreg,
  BB2o=BBslowreg, BBseqo=fBs*(BBfastseqreg+BBslowreg), ET2o = fet2 ET2reg, 
  ETseqo = (1-fet2) ET2reg}/. {opts} /. Options[qLungs];
    ExpandAll[int*Exp[(-lambda)*t]*(qAI1[t] + qAI2[t] + qAI3[t] + qbb1[t] + qbbseq[t] + qbb2[t] + qBB1[t] + 
          qBBseq[t] + qBB2[t] + qTH[t]) /. {sp -> SP, spt -> SPT, ss -> SS} /. {opts} /. Options[qLungs]]]; 

qLungsChronic[int_, ifd_, fra_, t1_, (lambda_)?NumericQ, opts___Rule] := 
   ExpandAll[Module[{t}, (qContinuousRT[1, {#1}, t, t1] & )[
       qLungs[int, ifd, fra, t, lambda, opts]]][[1]]]; 

qLungsContinuous[{int_, t_}, ifd_, fra_, t1_, (lambda_)?NumericQ, 
    opts___Rule] := ExpandAll[Module[{a, x1, t2, t3}, 
      a = qLungs[1, ifd, fra, t2, lambda, opts]; x1[t3_] = a /. t2 -> t3; 
       (qContinuousRT[int, {#1}, t, t1] & ) /@ x1[t]][[1]]]; 

qLungsMultiInputs[int_List, ifd_, fra_, t1_, (lambda_)?NumericQ, 
    opts___Rule] := ExpandAll[Module[{r1, t, t2, list1, list2}, 
      a = qLungs[1, ifd, fra, t, lambda, opts]; r1[t2_] = a /. t -> t2; 
       {list1, list2} = Transpose[Append[int, {0, t1}]]; 
       ListConvolve[list1, (r1[#1] & ) /@ Reverse[t1 + list2[[-2]] - 
           list2]]][[1]]]; 

LungsRetention["Acute", int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
qLungs[int, ifd, fra, t, lambda, opts];

LungsRetention["Constant", int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
qLungsChronic[int, ifd, fra, t, lambda, opts];

LungsRetention["Continuous", int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
qLungsContinuous[int, ifd, fra, t, lambda, opts];

LungsRetention["MultiInputs", int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
qLungsMultiInputs[int, ifd, fra, t, lambda, opts];

LungsRetention[int_, ifd_, fra_, t_, lambda_, opts___Rule] := 
Module[{meth}, meth = IntakeType /. {opts} /. Options[LungsRetention]; 
LungsRetention[meth, int, ifd, fra, t, lambda, opts]]; 

qSTfromRT[int_, {AIreg_, bbfastseqreg_, bbslowreg_, BBfastseqreg_, 
BBslowreg_, ET2reg_, ET1reg_}, 
{SP_, SPT_, SS_}, t_, lambda_, opts___Rule] := 
 Module[{ai}, ai = AIreg; {AI1o = fAI1*ai, 
    AI2o = fAI2*ai, AI3o = fAI3*ai, bb1o=(1-fbs)*bbfastseqreg-fbs*bbslowreg, 
bb2o=bbslowreg, bbseqo=fbs*(bbfastseqreg+bbslowreg), 
BB1o=(1-fBs)*BBfastseqreg-fBs*BBslowreg,
  BB2o=BBslowreg, BBseqo=fBs*(BBfastseqreg+BBslowreg), ET2o = fet2 ET2reg, 
  ETseqo = (1-fet2) ET2reg}/. {opts} /. Options[qRespTract]; 
  ExpandAll[int*Exp[-lambda*t]*qSt[t] /. {sp -> SP, spt -> SPT, ss -> SS} /. {opts} /. 
 Options[qRespTract]]];

qBfromRT[int_, {AIreg_, bbfastseqreg_, bbslowreg_, BBfastseqreg_, BBslowreg_, ET2reg_, ET1reg_}, 
     {SP_, SPT_, SS_}, t_, lambda_, opts___Rule] /; SPT == 0 := 
   Module[{ai}, ai = AIreg; {AI1o = fAI1*ai, 
    AI2o = fAI2*ai, AI3o = fAI3*ai, bb1o=(1-fbs)*bbfastseqreg-fbs*bbslowreg, bb2o=bbslowreg,
  bbseqo=fbs*(bbfastseqreg+bbslowreg), BB1o=(1-fBs)*BBfastseqreg-fBs*BBslowreg,
  BB2o=BBslowreg, BBseqo=fBs*(BBfastseqreg+BBslowreg), ET2o = fet2 ET2reg, 
  ETseqo = (1-fet2) ET2reg}/. {opts} /. Options[qRespTract];
ExpandAll[int*Exp[-lambda*t]*qBDiretNoT[t]/. {sp -> SP, spt -> SPT, ss -> SS} /. {opts} /. 
Options[qRespTract]]];

qBfromRT[int_, {AIreg_, bbfastseqreg_, bbslowreg_, BBfastseqreg_, BBslowreg_, ET2reg_, ET1reg_}, 
{SP_, SPT_, SS_}, t_, lambda_, opts___Rule] := 
Module[{ai}, ai = AIreg; {AI1o = fAI1*ai, 
    AI2o = fAI2*ai, AI3o = fAI3*ai, bb1o=(1-fbs)*bbfastseqreg-fbs*bbslowreg, bb2o=bbslowreg,
  bbseqo=fbs*(bbfastseqreg+bbslowreg), BB1o=(1-fBs)*BBfastseqreg-fBs*BBslowreg,
  BB2o=BBslowreg, BBseqo=fBs*(BBfastseqreg+BBslowreg), ET2o = fet2 ET2reg, 
  ETseqo = (1-fet2) ET2reg}/. {opts} /. Options[qRespTract];
  ExpandAll[int*Exp[-lambda*t]*qBDiret[t] /. {sp -> SP, spt -> SPT, ss -> SS} /. {opts} /. 
  Options[qRespTract]]]; 

End[]


Protect[q, qLungs, qET1, qRT2, qRTContinuous, qRTChronic, RespiratoryTract,
qLungsChronic, qLungsContinuous, qLungsMultiInputs, LungsRetention, 
AMADfit, AMADAdultW,  AMADAdultP,  AMADyr1, AMADyr10,qSTfromRT,qBfromRT]; 

Print["Resptract 1.2  2005-05-16"]

EndPackage[]
